@@ -12,15 +12,13 @@ PPIx::Regexp - Represent a regular expression of some sort
 
 =head1 DEPRECATION NOTICE
 
-The L<postderef|/postderef Boolean> argument to L<new()|/new> is being
-put through a deprecation cycle and retracted. After the retraction,
-postfix dereferences will always be recognized. This is the default
-behaviour now.
+The C<postderef> argument to L<new()|/new> is retracted, and
+postfix dereferences are always be recognized.
 
 Starting with version 0.074_01, the first use of this argument warned.
-warn. With version 0.079_01, all uses will warn. With version 0.080_01,
-all uses will become fatal. With the first release on or after April 15
-2022 all mention of this argument will be removed.
+With version 0.079_01, all uses warned. With version 0.080_01,
+all uses became fatal. With version 0.084_01, all mention of this
+argument was removed, except for this notice.
 
 =head1 INHERITANCE
 
@@ -196,9 +194,8 @@ use PPIx::Regexp::Util qw{
     __instance
 };
 use Scalar::Util qw{ refaddr };
-use Text::Tabs ();
 
-our $VERSION = '0.082';
+our $VERSION = '0.088';
 
 =head2 new
 
@@ -936,6 +933,10 @@ says what the various pieces of a regex do, though constructs added in
 perl 5.10 and later are not supported. I have no idea how I missed this
 when I originally went looking for C<Regexp> parsers.
 
+L<PPR|PPR>, which recognizes Perl of all sorts, including regular
+expressions, but does not actually provide a parse of the recognized
+constructs.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
@@ -949,7 +950,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2021 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
