@@ -36,7 +36,21 @@ use base qw{ PPIx::Regexp::Structure };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.084';
+our $VERSION = '0.088';
+
+sub __raw_width {
+    my ( $self ) = @_;
+    my $cond;
+    $cond = $self->schild( 0 )
+	and $cond->isa( 'PPIx::Regexp::Token::Condition' )
+	and $cond->content() eq '(DEFINE)'
+	and return ( 0, 0, 1 );
+    my ( $node_min, $node_max, $alternatives ) = $self->SUPER::__raw_width();
+    defined $node_min
+	and $alternatives < 2
+	and $node_min = 0;
+    return ( $node_min, $node_max, $alternatives );
+}
 
 sub __PPIX_LEXER__finalize {
     my ( $self, $lexer ) = @_;
@@ -103,7 +117,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2022 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
