@@ -36,12 +36,15 @@ use base qw{ PPIx::Regexp::Token::Reference };
 
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{
-    MINIMUM_PERL RE_CAPTURE_NAME
-    TOKEN_LITERAL TOKEN_UNKNOWN
+    MINIMUM_PERL
+    RE_CAPTURE_NAME
+    TOKEN_LITERAL
+    TOKEN_UNKNOWN
+    @CARP_NOT
 };
-use PPIx::Regexp::Util qw{ __to_ordinal_en };
+use PPIx::Regexp::Util qw{ __to_ordinal_en width };
 
-our $VERSION = '0.051';
+our $VERSION = '0.088';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -76,6 +79,49 @@ sub explain {
 
 }
 
+sub raw_width {
+    my ( $self ) = @_;
+    my $re = $self->top()
+	or return ( undef, undef );	# Shouldn't happen.
+    my @capture;
+    if ( $self->is_named() ) {
+	my $name = $self->name();
+	foreach my $elem ( @{ $re->find(
+	    'PPIx::Regexp::Structure::NamedCapture' ) || [] } ) {
+	    $elem->name() eq $name
+		or next;
+	    $re->__token_post_order( $elem, $self ) < 0
+		or last;
+	    push @capture, $elem;
+	}
+    } else {
+	my $number = $self->absolute();
+	foreach my $elem ( @{ $re->find(
+	    'PPIx::Regexp::Structure::Capture' ) || [] } ) {
+	    $elem->number() == $number
+		or next;
+	    $re->__token_post_order( $elem, $self ) < 0
+		or last;
+	    push @capture, $elem;
+	}
+    }
+    @capture == 1
+	and return $capture[0]->raw_width();
+    my ( $base_min, $base_max ) = $capture[0]->raw_width();
+    foreach my $elem ( @capture[ 1 .. $#capture ] ) {
+	my ( $ele_min, $ele_max ) = $elem->raw_width();
+	defined $ele_min
+	    or $base_min = undef;
+	defined $base_min
+	    and $base_min = $base_min == $ele_min ? $base_min : undef;
+	defined $ele_max
+	    or $base_max = undef;
+	defined $base_max
+	    and $base_max = $base_max == $ele_max ? $base_max : undef;
+    }
+    return ( $base_min, $base_max );
+}
+
 my @external = (	# Recognition used externally
     [ qr{ \A \( \? P = ( @{[ RE_CAPTURE_NAME ]} ) \) }smxo,
 	{ is_named => 1 },
@@ -85,8 +131,8 @@ my @external = (	# Recognition used externally
 my @recognize_regexp = (	# recognition used internally
     [
 	qr{ \A \\ (?:		# numbered (including relative)
-	    ( \d+ )	|
-	    g (?: ( -? \d+ ) | \{ ( -? \d+ ) \} )
+	    ( [0-9]+ )	|
+	    g (?: ( -? [0-9]+ ) | \{ ( -? [0-9]+ ) \} )
 	)
 	}smx, { is_named => 0 }, ],
     [
@@ -101,7 +147,7 @@ my @recognize_regexp = (	# recognition used internally
 my %recognize = (
     regexp	=> \@recognize_regexp,
     repl	=> [
-	[ qr{ \A \\ ( \d+ ) }smx, { is_named => 0 } ],
+	[ qr{ \A \\ ( [0-9]+ ) }smx, { is_named => 0 } ],
     ],
 );
 
@@ -178,7 +224,7 @@ sub __PPIX_LEXER__rebless {
     # be octal literals.
     my $content = $self->content();
     if ( $content =~ m/ \A \\ [0-7]{2,} \z /smx ) {
-	bless $self, TOKEN_LITERAL;
+	TOKEN_LITERAL->__PPIX_ELEM__rebless( $self );
 	return 0;
     }
 
@@ -190,8 +236,7 @@ sub __error {
     my ( $self, $msg ) = @_;
     defined $msg
 	or $msg = 'No corresponding capture group';
-    $self->{error} = $msg;
-    bless $self, TOKEN_UNKNOWN;
+    TOKEN_UNKNOWN->__PPIX_ELEM__rebless( $self, error => $msg );
     return 1;
 }
 
@@ -202,7 +247,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -210,7 +257,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
